==> pyvyos-0.2.0.tar.gz: pyvyos-0.2.0/CONTRIB.md <==
# Contributing to PyVyOS

We welcome contributions to the PyVyOS project! If you're looking to contribute, please take a moment to read this guide to understand how you can be a part of our community and help make PyVyOS better.

## Code of Conduct

We expect all contributors to adhere to our Code of Conduct. Respectful, collaborative behavior is crucial to maintaining a healthy environment.

## How to Contribute

There are many ways to contribute to PyVyOS:

- **Submitting bug reports and feature requests:** Use our issue tracker to report bugs or suggest features.
- **Writing code:** Feel free to take on open issues or propose new changes. Please follow the guidelines outlined below.
- **Improving documentation:** Good documentation is crucial. Contributions to improve or clarify documentation are always appreciated.

## Development Process

1. **Fork and Clone the Repository**
   - Start by forking the repository and then cloning it to your local machine.

2. **Set Up Your Environment**
   - We recommend using Poetry for dependency management. Ensure you have Poetry installed and then run `poetry install` to set up your environment.

3. **Create a Feature Branch**
   - Create a branch for your feature or bugfix, e.g., `git checkout -b feature/add-new-command`.

4. **Write Your Code**
   - Write your code following Python best practices and adhering to PEP 8.
   - Include comments where necessary to explain complex parts of your code.

5. **Write Tests**
   - We use PyTest for testing. Please add tests for your code and ensure all tests pass.

6. **Document Your Changes**
   - Update the README.md or documentation if your changes require it.

7. **Commit Your Changes**
   - Use clear and descriptive commit messages.
   - Make sure to commit your changes regularly.

8. **Push to Your Fork and Submit a Pull Request**
   - Push your changes to your fork and then submit a pull request to our repository.
   - In your pull request, clearly describe the changes and their purpose.

## Code Review Process

- After you submit a pull request, the project maintainers will review your code.
- Be open to feedback and willing to make changes to your code.
- Once your pull request is approved, a maintainer will merge it.

## Reporting Bugs

- Use GitHub Issues to report bugs.
- Be as detailed as possible in your bug report. Include steps to reproduce the bug and any relevant logs or screenshots.

## Suggesting Enhancements

- Use GitHub Issues to suggest enhancements.
- Clearly explain the suggested feature and its benefits.

## License

By contributing to PyVyOS, you agree that your contributions will be licensed under the same license that covers the project.

Thank you for considering contributing to PyVyOS. Your efforts are what make this project great!

==> pyvyos-0.2.2.tar.gz: pyvyos-0.2.2/CONTRIB.md <==
# Contributing to pyvyos

We welcome contributions to the pyvyos project! If you're looking to contribute, please take a moment to read this guide to understand how you can be a part of our community and help make pyvyos better.

## Code of Conduct

We expect all contributors to adhere to our Code of Conduct. Respectful, collaborative behavior is crucial to maintaining a healthy environment.

## How to Contribute

There are many ways to contribute to pyvyos:

- **Submitting bug reports and feature requests:** Use our issue tracker to report bugs or suggest features.
- **Writing code:** Feel free to take on open issues or propose new changes. Please follow the guidelines outlined below.
- **Improving documentation:** Good documentation is crucial. Contributions to improve or clarify documentation are always appreciated.

## Development Process

1. **Fork and Clone the Repository**
   - Start by forking the repository and then cloning it to your local machine.

2. **Set Up Your Environment**
   - We recommend using Poetry for dependency management. Ensure you have Poetry installed and then run `poetry install` to set up your environment.

3. **Create a Feature Branch**
   - Create a branch for your feature or bugfix, e.g., `git checkout -b feature/add-new-command`.

4. **Write Your Code**
   - Write your code following Python best practices and adhering to PEP 8.
   - Include comments where necessary to explain complex parts of your code.

5. **Write Tests**
   - We use PyTest for testing. Please add tests for your code and ensure all tests pass.

6. **Document Your Changes**
   - Update the README.md or documentation if your changes require it.

7. **Commit Your Changes**
   - Use clear and descriptive commit messages.
   - Make sure to commit your changes regularly.

8. **Push to Your Fork and Submit a Pull Request**
   - Push your changes to your fork and then submit a pull request to our repository.
   - In your pull request, clearly describe the changes and their purpose.

## Code Review Process

- After you submit a pull request, the project maintainers will review your code.
- Be open to feedback and willing to make changes to your code.
- Once your pull request is approved, a maintainer will merge it.

## Reporting Bugs

- Use GitHub Issues to report bugs.
- Be as detailed as possible in your bug report. Include steps to reproduce the bug and any relevant logs or screenshots.

## Suggesting Enhancements

- Use GitHub Issues to suggest enhancements.
- Clearly explain the suggested feature and its benefits.

## License

By contributing to pyvyos, you agree that your contributions will be licensed under the same license that covers the project.

Thank you for considering contributing to pyvyos. Your efforts are what make this project great!
